# 📁 `lsoph`

TUI that lists open files for a given process.

Usage:

```shell
uvx lsoph -p <pid>
```

* [🎬 demo](https://asciinema.org/a/c7T8id39jU7ap6E0D99S5dJ6F)
* [🏠 home](https://bitplane.net/dev/python/lsoph)
* [🐱 github](https://github.com/bitplane/lsoph)
* [🐍 pypi](https://pypi.org/project/lsoph)

